## Changelog

Richard de Vos <rdevos72@gmail.com>
fhs_iptv_tools
fhs-iptv-tools

Shortlist to come:
------------------

- download m3u file from url
- and lots more (just request on github)

--------------------------------------------------------------
- 0.8.0: initial creation
- 0.8.1: add select, delete_channels, add_channel
- 0.8.2: add save_m3u (so now this program is usable)
- 0.8.3: add modify_channel, change channel id, name, group_title, and logo and small bug in display channel
- 0.8.4: add copy_channels to copy channels and list_stores to list current stores.
- 0.8.5: fix missing dependancy (pyyaml), add clear tag and change add copy of dataclass struct on copy_channel function
- 0.8.6: add move, select_and_copy, select_and_move options
- 0.8.7: add sorted options and add cleanup of save_tasks command.
- 0.8.8: change documentation
- 0.8.9: some small changes and add a run_tasks command, to load and use a task file from interactive mode, changed some default values
- 0.8.10: add loop function for tasks with example.
